@@ -173,6 +173,30 @@ class Smartfire(object):
             raise EconetUninitilized
         return sensor
 
+    @property
+    def huw_pump(self) -> str:
+        if (sensor := self.sensors.get("huw_pump")) is None:
+            raise EconetUninitilized
+        return sensor
+
+    @property
+    def central_heating_pump(self) -> str:
+        if (sensor := self.sensors.get("central_heating_pump")) is None:
+            raise EconetUninitilized
+        return sensor
+
+    @property
+    def circulating_pump(self) -> str:
+        if (sensor := self.sensors.get("circulating_pump")) is None:
+            raise EconetUninitilized
+        return sensor
+
+    @property
+    def boiler_pump(self) -> str:
+        if (sensor := self.sensors.get("boiler_pump")) is None:
+            raise EconetUninitilized
+        return sensor
+
     @property
     def attributes(self) -> dict:
         return self._attrs
@@ -203,6 +227,14 @@ class Smartfire(object):
             self.sensors["feeder_temperature"] = Sensor(
                 self._econet, Params.FEEDER_TEMPERATURE
             )
+            self.sensors["huw_pump"] = Sensor(self._econet, Params.HUW_PUMP)
+            self.sensors["central_heating_pump"] = Sensor(
+                self._econet, Params.PUMP_MIXER_1
+            )
+            self.sensors["circulating_pump"] = Sensor(
+                self._econet, Params.CIRCULATING_PUMP
+            )
+            self.sensors["boiler_pump"] = Sensor(self._econet, Params.BOILER_PUMP)
             sys = await self._econet.fetch_sys_params()
             self._attrs = {
                 "uid": sys["uid"],
